@@ -20,7 +20,7 @@ Net::WebSocket::Frame::close
 
     $frm->get_type();           #"close"
 
-    $frm->is_control_frame();   #1
+    $frm->is_control();   #1
 
     my $mask = $frm->get_mask_bytes();
 
@@ -38,8 +38,13 @@ close messages can have any of:
 
 =item * no code, and no reason
 
+Returned as undef (for the code) and an empty string. This diverges
+from the RFC’s described behavior of returning code 1005.
+
 =item * a code, and no reason
 
+Returned as the code number and an empty string.
+
 =item * a code, and a reason that cannot exceed 123 bytes
 
 =back
@@ -47,7 +52,7 @@ close messages can have any of:
 The code (i.e., C<$code>) is subject to
 L<the limitations that RFC 6445 describes|https://tools.ietf.org/html/rfc6455#section-7.4>.
 You can also, in lieu of a numeric constant, use the following string
-constants that L<Microsoft defines|https://msdn.microsoft.com/en-us/library/windows/desktop/hh449350(v=vs.85).aspx>:
+constants that derive from L<Microsoft’s WebSocket API|https://msdn.microsoft.com/en-us/library/windows/desktop/hh449350(v=vs.85).aspx>:
 
 =over
 
@@ -67,20 +72,34 @@ constants that L<Microsoft defines|https://msdn.microsoft.com/en-us/library/wind
 
 =item * C<UNSUPPORTED_EXTENSIONS> (1010)
 
-=item * C<SERVER_ERROR> (1011)
+=item * C<INTERNAL_ERROR>, aka C<SERVER_ERROR> (1011)
 
-NOTE: As per L<erratum|https://www.rfc-editor.org/errata_search.php?rfc=6455>
-3227, this status is meant to encompass client errors as well. Since these
-constants are meant to match Microsoft’s (in default of such in the actual
-WebSocket standard), however, Net::WebSocket only recognizes C<SERVER_ERROR>
-as an alias of 1011. Hopefully a future update to the WebSocket standard will
-include useful string aliases for the status codes.
+This appears as C<SERVER_ERROR> in Microsoft’s documentation; however,
+L<erratum 3227|https://www.rfc-editor.org/errata_search.php?rfc=6455> updates
+the RFC to have this status encompass client errors as well.
 
-Also note that L<the official list of status codes|http://www.iana.org/assignments/websocket/websocket.xhtml#close-code-number> contains some that
-don’t have string constants.
+Net::WebSocket recognizes either string, but its parsing logic will return
+only C<INTERNAL_ERROR>.
 
 =back
 
+The following additional status constants derive from
+L<the official registry of status codes|http://www.iana.org/assignments/websocket/websocket.xhtml#close-code-number>
+and are newer than either RFC 6455 or Microsoft’s API:
+
+=over
+
+=item * C<SERVICE_RESTART> (1012)
+
+=item * C<TRY_AGAIN_LATER> (1013)
+
+=item * C<BAD_GATEWAY> (1014)
+
+=back
+
+It is hoped that a future update to the WebSocket specification
+can include these or similar constant names.
+
 =cut
 
 use strict;
@@ -93,6 +112,7 @@ use parent qw(
 use Call::Context ();
 
 use Net::WebSocket::Constants ();
+use Net::WebSocket::X ();
 
 use constant get_opcode => 8;
 
@@ -102,10 +122,10 @@ sub new {
     if (!$opts{'payload_sr'} && !defined $opts{'payload'}) {
         my $payload;
 
-        if ($opts{'code'}) {
-            my $num = Net::WebSocket::Constants::status_name_to_code($opts{'code'});
+        if (my $code = delete $opts{'code'}) {
+            my $num = Net::WebSocket::Constants::status_name_to_code($code);
             if (!$num) {
-                $num = $opts{'code'};
+                $num = $code;
 
                 if ($num !~ m<\A[0-9]{4}\z> ) {
                     die Net::WebSocket::X->create('BadArg', 'code', $num, 'Invalid WebSocket status code');
@@ -120,12 +140,13 @@ sub new {
 
             $payload = pack 'n', $num;
 
-            if (defined $opts{'reason'}) {
-                if (length $opts{'reason'} > 123) {
-                    die Net::WebSocket::X->create('BadArg', 'reason', $opts{'reason'}, 'Reason cannot exceed 123 bytes!');
+            my $reason = delete $opts{'reason'};
+            if (defined $reason) {
+                if (length $reason > 123) {
+                    die Net::WebSocket::X->create('BadArg', 'reason', $reason, 'Reason cannot exceed 123 bytes!');
                 }
 
-                $payload .= $opts{'reason'};
+                $payload .= $reason;
             }
         }
         else {
@@ -149,7 +170,9 @@ sub get_code_and_reason {
         die "Frame type is “$type”, not “close” as expected!";
     }
 
-    return if !length ${ $self->[$self->PAYLOAD] };
+    if (!length ${ $self->[$self->PAYLOAD] }) {
+        return ( undef, q<> );
+    }
 
     return unpack 'na*', $self->get_payload();
 }
