@@ -8,20 +8,25 @@ Net::WebSocket::Frame::text
 
 =head1 SYNOPSIS
 
+B<NOTE:> Before you instantiate this class directly, look at
+L<Net::WebSocket::Endpoint>’s C<create_message()> convenience
+method to make your life easier.
+
     my $frm = Net::WebSocket::Frame::text->new(
 
         #This flag defaults to on
         fin => 1,
 
-        #Optional, can be either empty (default) or four random bytes
+        #For servers, this must be empty (default).
+        #For clients, this must be four random bytes.
         mask => q<>,
 
-        payload_sr => \$payload_text,
+        payload => $payload_text,
     );
 
     $frm->get_type();           #"text"
 
-    $frm->is_control_frame();   #0
+    $frm->is_control();   #0
 
     my $mask = $frm->get_mask_bytes();
 
